@@ -3,10 +3,10 @@ Overview:
     Isolation for directory.
 """
 import os
-import tempfile
 from contextlib import contextmanager
 from typing import ContextManager, Dict, Optional
 
+from .._base import TemporaryDirectory
 from ...system import copy
 
 __all__ = [
@@ -58,7 +58,7 @@ def isolated_directory(mapping: Optional[Dict[str, str]] = None) -> ContextManag
 
     """
     _original_path = os.path.abspath(os.curdir)
-    with tempfile.TemporaryDirectory() as dirname:
+    with TemporaryDirectory() as dirname:
         for dst, src in (mapping or {}).items():
             dst_position = os.path.join(dirname, dst)
             os.makedirs(os.path.dirname(dst_position), exist_ok=True)
